![pytest](https://github.com/ing-bank/doing-cli/workflows/Release/badge.svg)
![pytest](https://github.com/ing-bank/doing-cli/workflows/Development/badge.svg)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/doing-cli)
![PyPI](https://img.shields.io/pypi/v/doing-cli)
![PyPI - License](https://img.shields.io/pypi/l/doing-cli)
![PyPI - Downloads](https://img.shields.io/pypi/dm/doing-cli)
![GitHub contributors](https://img.shields.io/github/contributors/ing-bank/doing-cli)

# doing-cli: Azure Devops on the command line

CLI app to help speed up development on Azure DevOps, built on top of [azure devops cli](). Allows for a more streamlined repo/issue workflow. Inspired by [cli.github.com](https://cli.github.com/). 

## Installation

`doing` requires python 3.6+, [azure cli](https://docs.microsoft.com/en-us/cli/azure/install-azure-cli) and the [devops extension](https://docs.microsoft.com/en-us/azure/devops/cli/?view=azure-devops). To install:

```shell
pip3 install doing-cli
```

For more details and setup see the [installation guide](https://ing-bank.github.io/doing-cli/get_started/install/).

## Documentation

See [ing-bank.github.io/doing-cli/](https://ing-bank.github.io/doing-cli/).
